"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.copyComment = exports.removeUndefined = void 0;
const models_1 = require("../../models");
function removeUndefined(type) {
    if (type instanceof models_1.UnionType) {
        const types = type.types.filter((t) => {
            if (t instanceof models_1.IntrinsicType) {
                return t.name !== "undefined";
            }
            return true;
        });
        if (types.length === 1) {
            return types[0];
        }
        type.types = types;
        return type;
    }
    return type;
}
exports.removeUndefined = removeUndefined;
/**
 * Copy the comment of the source reflection to the target reflection.
 * Performs the copy according to the specification at https://tsdoc.org/pages/tags/inheritdoc/.
 * Mostly.
 *
 * @param target - Reflection with comment containing `@inheritDoc` tag
 * @param source - Referenced reflection
 */
function copyComment(target, source) {
    if (target.comment &&
        source.comment &&
        target.comment.getTag("@inheritDoc")) {
        // GERRIT This seems wrong. Shouldn't be overwriting parameters or type parameters...
        if (target instanceof models_1.DeclarationReflection &&
            source instanceof models_1.DeclarationReflection) {
            target.typeParameters = source.typeParameters;
        }
        else if (target instanceof models_1.SignatureReflection &&
            source instanceof models_1.SignatureReflection) {
            target.parameters = source.parameters;
            target.typeParameters = source.typeParameters;
        }
        target.comment.summary = models_1.Comment.cloneDisplayParts(source.comment.summary);
        target.comment.removeTags("@remarks");
        target.comment.removeTags("@inheritDoc"); // Remove block level inheritDoc
        const remarks = source.comment.getTag("@remarks");
        if (remarks) {
            target.comment.blockTags.push(remarks.clone());
        }
    }
    else if (!target.comment && source.comment) {
        if (target instanceof models_1.DeclarationReflection &&
            source instanceof models_1.DeclarationReflection) {
            target.typeParameters = source.typeParameters;
        }
        target.comment = source.comment.clone();
    }
}
exports.copyComment = copyComment;
