"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.comment = void 0;
const utils_1 = require("../../../../utils");
const lib_1 = require("../../lib");
function displayPartsToMarkdown(parts, urlTo) {
    const result = [];
    for (const part of parts) {
        switch (part.kind) {
            case "text":
            case "code":
                result.push(part.text);
                break;
            case "inline-tag":
                switch (part.tag) {
                    case "@label":
                    case "@inheritdoc": // Shouldn't happen
                        break; // Not rendered.
                    case "@link":
                    case "@linkcode":
                    case "@linkplain": {
                        if (part.target) {
                            const url = typeof part.target === "string" ? part.target : urlTo(part.target);
                            const wrap = part.tag === "@linkcode" ? "`" : "";
                            result.push(url ? `[${wrap}${part.text}${wrap}](${url})` : part.text);
                        }
                        else {
                            result.push(part.text);
                        }
                        break;
                    }
                    default:
                        // Hmm... probably want to be able to render these somehow, so custom inline tags can be given
                        // special rendering rules. Future capability. For now, just render their text.
                        result.push(`{${part.tag} ${part.text}}`);
                        break;
                }
                break;
            default:
                (0, utils_1.assertNever)(part);
        }
    }
    return result.join("");
}
function comment({ markdown, urlTo }, props) {
    if (!props.comment?.hasVisibleComponent())
        return;
    // Note: Comment modifiers are handled in `renderFlags`
    return (utils_1.JSX.createElement("div", { class: "tsd-comment tsd-typography" },
        utils_1.JSX.createElement(utils_1.Raw, { html: markdown(displayPartsToMarkdown(props.comment.summary, urlTo)) }),
        props.comment.blockTags.map((item) => (utils_1.JSX.createElement(utils_1.JSX.Fragment, null,
            utils_1.JSX.createElement("h3", null, (0, lib_1.camelToTitleCase)(item.tag.substring(1))),
            utils_1.JSX.createElement(utils_1.Raw, { html: markdown(displayPartsToMarkdown(item.content, urlTo)) }))))));
}
exports.comment = comment;
